import re


def find_splitter(string):
    ol = r"\d+\."
    string = string.strip()
    if "\n" in string:
        sep = "\n"
    elif "," in string:
        sep = ","
    elif re.match(ol, string):
        sep = ol
    elif " " in string:
        sep = " "
    else:
        return None

    return re.compile(sep)


def str2list(content):
    """
    Input is any string. This function finds a main seperator in
    given string and split the string into parts with the main seperator
    """
    sep = find_splitter(content)
    # print("sep: \"{}\";".format(sep))
    l = []
    for part in sep.split(content):
        part = part.strip()
        if part != "":
            l.append(part)

    return l



from distutils.core import setup

setup(
  name='calio-toolbox',
  version='0.0.1',
  author='calio',
  author_email='vipcalio@gmail.com',
  url='https://gitlab.com/calio/toolbox',
  license="MIT",
  long_description="A collections of tools and libraries by calio",
  packages=['toolbox'],
  scripts=['bin/list']
)


from toolbox.list import str2list


def test_answer():
    s = "aa bb cc dd"
    assert str2list(s) == ["aa", "bb", "cc", "dd"]

    s = "aa, bb, cc, dd"
    assert str2list(s) == ["aa", "bb", "cc", "dd"]

    s = "1. aa 2. bb 3. cc 4. dd"
    assert str2list(s) == ["aa", "bb", "cc", "dd"]

